

class UserDefined:
    def setup(self):
        """TODO"""
        pass

    def draw(self):
        """TODO"""
        pass

    def cleanup(self):
        """TODO"""
        pass

    def key_pressed(self, key):
        """TODO"""
        pass

    def window_resized(self):
        """TODO"""
        self.screen.clear()
